@@ -5,6 +5,7 @@
 
 import sys
 import os.path
+import sumolib.utils
 
 if __name__ == "__main__":
     # if this module is directly called like a script, we have to add the path
@@ -16,21 +17,11 @@ if __name__ == "__main__":
 import sumolib.ModuleSpec
 import sumolib.JSON
 
-__version__="4.1.5" #VERSION#
+__version__="4.2" #VERSION#
 
 assert __version__==sumolib.ModuleSpec.__version__
 assert __version__==sumolib.JSON.__version__
 
-# -----------------------------------------------
-# warnings
-# -----------------------------------------------
-
-def warn(text):
-    """print a warning to the console."""
-    sys.stdout.flush()
-    sys.stderr.write(text+"\n")
-    sys.stderr.flush()
-
 # -----------------------------------------------
 # class definitions
 # -----------------------------------------------
@@ -122,15 +113,15 @@ class DB(sumolib.JSON.Container):
         d= self.datadict()
         od= other.datadict()
         new_builds= set()
+        ignored_builds= set()
         for b in other.iter_builds():
             if self.has_build_tag(b):
-                warn(("warning: buildtag '%s' found in both build databases, "
-                      "the later one will be ignored.") % b)
+                ignored_builds.add(b)
                 continue
             # note: this is *NOT* a deepcopy, just the reference is copied:
             d[b]= od[b]
             new_builds.add(b)
-        return new_builds
+        return (new_builds, ignored_builds)
     def is_empty(self):
         """shows of the object is empty."""
         return not bool(self.datadict())
@@ -247,7 +238,8 @@ class DB(sumolib.JSON.Container):
         while changes:
             loopcount+=1
             if loopcount > 100:
-                warn("warning: internal error, sortby_linkage failed")
+                sumolib.utils.errmessage(\
+                    "warning: internal error, sortby_linkage failed")
                 break
             changes= False
             for t in taglist:
@@ -371,6 +363,7 @@ class DB_overlay(DB):
         self.overlay_keys= {}
         self.overlay_files= []
         self.overlay_mode= True
+        self.ignored_keys= set()
     def overlaymode(self, new_mode= None):
         """get or set the overlay mode.
 
@@ -390,7 +383,16 @@ class DB_overlay(DB):
         """merge with another builddb from a file."""
         other= DB.from_json_file(filename, use_lock= use_lock,
                                  keep_lock= False)
-        new_keys= self.merge(other)
+        (new_keys, ignored_keys)= self.merge(other)
+        if ignored_keys:
+            sumolib.utils.errmessage(\
+                ("Warning: The following build tags in %s were ignored "
+                 "since they already exist in %s:") % \
+                 (filename, self._filename))
+            sumolib.utils.errmessage(" ".join(sorted(ignored_keys)))
+            # list of builds:
+            # (sumo build list 2>&1 >/dev/null) | tail -n +1
+
         self.overlay_files.append(filename)
         idx= len(self.overlay_files)-1
         for k in new_keys:
@@ -492,9 +494,10 @@ class BuildCache(sumolib.JSON.Container):
                     dep_names= list(db.iter_dependencies(modulename,
                                                          versionname))
                 except KeyError as _:
-                    warn("WARNING: build '%s', module '%s:%s' not "
+                    sumolib.utils.errmessage(\
+                        ("WARNING: build '%s', module '%s:%s' not "
                          "in dependency db!" % \
-                         (buildtag,modulename,versionname))
+                         (buildtag,modulename,versionname)))
                     continue
                 for dep_name in dep_names:
                     v= build_dict.get(dep_name)
