@@ -1,7 +1,7 @@
 """Repository support
 """
 
-# pylint: disable=invalid-name, bad-whitespace
+# pylint: disable=invalid-name
 
 import os.path
 import sys
@@ -18,7 +18,7 @@ import sumolib.git
 import sumolib.subversion # "svn"
 import sumolib.cvs
 
-__version__="4.1.5" #VERSION#
+__version__="4.2" #VERSION#
 
 assert __version__==sumolib.utils.__version__
 assert __version__==sumolib.lock.__version__
@@ -191,7 +191,7 @@ class SourceSpec(sumolib.JSON.Container):
             # sumolib.JSON.Container defines __del__(). We handle this problem
             # in function __del__ in sumolib.JSON.
             raise ValueError("invalid source spec dict %s" % repr(dict_))
-        super(SourceSpec, self).__init__(dict_, use_lock= True)
+        super().__init__(dict_, use_lock= True)
     # pylint: disable=C0301
     #                          Line too long
     def to_deps_dict(self):
@@ -592,11 +592,10 @@ class ManagedRepo():
             # Setting self.sourcespec to <None> basically disables the
             # ManagedRepo object.
             if self.mode!='get':
-                sys.stdout.flush()
-                sys.stderr.write(("warning: locking the dependency database "
-                                  "failed: '%s'. Disabling repository "
-                                  "operations on the dependency database "
-                                  "for now.") % errmsg)
+                sumolib.utils.errmessage(\
+                    ("warning: locking the dependency database failed: "
+                     "%s. Disabling repository operations on the "
+                     "dependency database for now.") % errmsg)
                 sys.stderr.flush()
             self.sourcespec= None
             return
@@ -620,11 +619,10 @@ class ManagedRepo():
             if self.repo_obj.get_remote_url() is None:
                 # repo found but remote repo couldn't be contacted:
                 self.mode='get'
-                sys.stdout.flush()
-                sys.stderr.write("warning: remote repository for dependency "
-                                 "database repository couldn't be "
-                                 "contacted, forcing mode 'get'.\n")
-                sys.stderr.flush()
+                sumolib.utils.errmessage(\
+                    "warning: remote repository for dependency "
+                    "database repository couldn't be contacted, "
+                    "forcing mode 'get'.")
 
     def local_changes(self):
         """return if there are local changes."""
