@@ -1,17 +1,18 @@
 """Utilities for the SUMO scripts.
 """
 
-# pylint: disable=invalid-name, bad-whitespace
+# pylint: disable=invalid-name
 
 import sys
 import platform
 import os
 import os.path
 import re
+import textwrap
 import sumolib.system
 import sumolib.JSON
 
-__version__="4.1.5" #VERSION#
+__version__="4.2" #VERSION#
 
 # The following variable may be set to True when
 # we have to see on stderr when sumo is waiting for
@@ -98,8 +99,8 @@ def ask_from_options(question, options):
             if _trace_input:
                 sys.stderr.write("(wait for input on stdin)\n")
             inp= input(question).strip()
-        except EOFError as _:
-            raise EOFError("EOF while waiting for input")
+        except EOFError as e:
+            raise EOFError("EOF while waiting for input") from e
         if inp in options:
             return inp
         # not found
@@ -125,8 +126,8 @@ def ask_yes_no(question, force_yes= None):
             if _trace_input:
                 sys.stderr.write("(wait for input on stdin)\n")
             inp= input(question).lower().strip()
-        except EOFError as _:
-            raise EOFError("EOF while waiting for input")
+        except EOFError as e:
+            raise EOFError("EOF while waiting for input") from e
         if inp in ["yes","y"]:
             return True
         if inp in ["no", "n"]:
@@ -168,6 +169,26 @@ def env_expand(st):
         return st
     return os.path.expandvars(st.replace(r'\$',"$ ")).replace("$ ","$")
 
+def linebreaks(txt, initial_indent, subsequent_indent, final_linefeed= True):
+    """text wrap."""
+    lines= textwrap.wrap(txt, initial_indent= initial_indent,
+                         subsequent_indent= subsequent_indent,
+                         break_on_hyphens= False)
+    if final_linefeed:
+        lines.append("")
+    return "\n".join(lines)
+
+def errmessage(txt, initial_indent="", subsequent_indent="  ", wrap= True):
+    """print something on stderr."""
+    sys.stdout.flush()
+    if not wrap:
+        sys.stderr.write(txt+'\n')
+    else:
+        sys.stderr.write(linebreaks(txt,
+                                    initial_indent= initial_indent,
+                                    subsequent_indent= subsequent_indent))
+    sys.stderr.flush()
+
 rx_ivar= re.compile(r'(?<!\\)\$([A-Za-z_]\w*)')
 rx_ivar2= re.compile(r'(?<!\\)\$\{([A-Za-z_]\w*)\}')
 
@@ -365,6 +386,7 @@ class TextFile:
             if self.dry_run:
                 self.fh= None
             else:
+                # pylint: disable=consider-using-with
                 self.fh= open(filename, "w")
     def write(self, st):
         """write a text."""
